@@ -22,7 +22,7 @@ Put page
     ...     ('body', 'foo\\nbar'),
     ... ))
 
-    >>> path = './content/my#url.yml'
+    >>> path = './content/#my#url.yml'
     >>> print open(path).read()
     title: foo
     body: |-
@@ -58,7 +58,7 @@ class YamlPage(object):
             >>> obj.url_to_path('a/b/c')
             'root/dir/a#b#c.yml'
         '''
-        filename = url.lstrip('/').replace('/', '#') + '.yml'
+        filename = url.replace('/', '#') + '.yml'
         return os.path.join(self.root_dir, filename)
 
     def get(self, url):
